@@ -13,7 +13,7 @@
 ##############################################################################
 """Hello Worl Message Implementation
 
-$Id: message.py 75942 2007-05-24 14:53:46Z srichter $
+$Id: message.py 77311 2007-07-02 18:53:39Z srichter $
 """
 __docformat__ = "reStructuredText"
 import persistent
@@ -33,6 +33,3 @@ class HelloWorld(location.Location, persistent.Persistent):
         self.who = who
         self.when = when
         self.what = what
-
-    def __repr__(self):
-        return '<%s from %r>' %(self.__class__.__name__, self.who)
